@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : Frames.py
-Version : 1.5.3
+Version : 1.7.0
 Author  : Stefano Covino
-Date    : 19/08/2013
+Date    : 16/10/2013
 E-mail  : stefano.covino@brera.inaf.it
 URL:    : http://www.merate.mi.astro.it/utenti/covino
 
@@ -32,6 +32,9 @@ History : (27/09/2010) First version.
         : (04/11/2011) More flexibility in header coordinate format.
         : (22/01/2012) Check that at least one catalogue returns data.
         : (19/08/2013) Data saved with the original format.
+        : (29/08/2013) Tunable tolerance for triangle match. Do not update RA,DEC if they already exist.
+        : (03/09/2013) Better search of catalogue objects.
+        : (16/10/2013) Better computation of frame center.
 """
 
 
@@ -195,8 +198,14 @@ class Astrometry:
             self.EclipseSources = False
             #
             self.DefineWCSHeader()
-                
-                
+  
+  
+    def GetFrameCenterCoords(self):
+            cc = self.FitsFrame.GetFrameCenterPix()
+            cpos = Pixel2WCS(self.FitsFrame.Header,[cc])
+            return cpos[0]
+  
+  
     def GetSources(self, maxobjs=15, thre=23, mincnnt=3, cleanperc=1.):
             soglia = copy.copy(thre)
             while len(self.List) < maxobjs and soglia > 1: 
@@ -244,7 +253,12 @@ class Astrometry:
                     
     def GetCatSources(self, maxentr=15, catq='N'): 
             radius = 1.5*self.HalfSize*60.0  # arcmin
-            cntfld = (self.RA,self.DEC)
+            #cntfld = (self.RA,self.DEC)
+            crd = self.GetFrameCenterCoords()
+            inpcoord = AstroCoordInput(crd[0],crd[1])
+            cntfld = (inpcoord.RA, inpcoord.DEC)
+            #print cntfld
+            #
             if catq == 'N':
                 cat = TWOMASS(cntfld[0], cntfld[1], math.floor(radius))
             elif catq == 'O':
@@ -285,13 +299,15 @@ class Astrometry:
         self.FitsFrame.Header.update(FitsConstants.CRPIX1,self.CRPIX1,FitsConstants.CRPIX1Cmt)
         self.FitsFrame.Header.update(FitsConstants.CRPIX2,self.CRPIX2,FitsConstants.CRPIX1Cmt)
         # pointing dir
-        self.FitsFrame.Header.update(FitsConstants.RA,self.RA)
-        self.FitsFrame.Header.update(FitsConstants.DEC,self.DEC)                        
+        if not (FitsConstants.RA in self.FitsFrame.Header.keys()):
+            self.FitsFrame.Header.update(FitsConstants.RA,self.RA)
+        if not (FitsConstants.DEC in self.FitsFrame.Header.keys()):
+            self.FitsFrame.Header.update(FitsConstants.DEC,self.DEC)                        
         self.FitsFrame.Header.update(FitsConstants.RADECSys,FitsConstants.RADECSysVal)  
         self.FitsFrame.Header.update(FitsConstants.AngUnit1,FitsConstants.AngUnit1Val,FitsConstants.AngUnCmt)
         self.FitsFrame.Header.update(FitsConstants.AngUnit2,FitsConstants.AngUnit2Val,FitsConstants.AngUnCmt) 
         #
-        self.FitsFrame.WCS.updateFromHeader()  
+        self.FitsFrame.WCS.updateFromHeader()
 #        print self.CRVAL1, self.CRVAL2
 
 
@@ -347,7 +363,7 @@ class Astrometry:
         self.RotationAngle = self.RotationAngle + rot
                     
                                     
-    def FindSolution(self):
+    def FindSolution(self,angtol=0.5,disttol=5.):
         reflist = []
         objlist = []
         # centering
@@ -372,7 +388,9 @@ class Astrometry:
             reflist.append(((i[0]-RefPos[0][0]), (i[1]-RefPos[0][1])))
             #print reflist[-1]
         #
-        mtchres = TriangleMatch(reflist,objlist)
+        self.REFCDR = reflist
+        self.OBJCDR = objlist
+        mtchres = TriangleMatch(reflist,objlist,angtol,disttol)
         if mtchres != None:
 #            print mtchres
             mtchinplist = []
@@ -419,8 +437,10 @@ class Astrometry:
     def GetPointingShift(self):
         # derive true center coordinate
         ccord = Pixel2WCS(self.FitsFrame.Header,[(self.FrameCenter[0],self.FrameCenter[1])])
-        self.RAshift = ((self.RA - ccord[0][0])*math.cos(math.radians(self.DEC)))*3600.0
-        self.DECshift = (self.DEC - ccord[0][1])*3600.0
+#        self.RAshift = ((self.RA - ccord[0][0])*math.cos(math.radians(self.DEC)))*3600.0
+#        self.DECshift = (self.DEC - ccord[0][1])*3600.0
+        self.RAshift = ((self.FitsFrame.Header[FitsConstants.RA] - ccord[0][0])*math.cos(math.radians(self.FitsFrame.Header[FitsConstants.DEC])))*3600.0
+        self.DECshift = (self.FitsFrame.Header[FitsConstants.DEC] - ccord[0][1])*3600.0
 
             
     def SaveFile(self,nfile):
@@ -449,3 +469,5 @@ class Astrometry:
         warnings.resetwarnings() 
         warnings.filterwarnings('always', category=UserWarning, append=True)
 
+
+
