@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : Frames
-Version : 1.0.2
+Version : 1.0.3
 Author  : Stefano Covino
-Date    : 05/02/2012
+Date    : 18/08/2013
 E-mail  : stefano.covino@brera.inaf.it
 URL:    : http://www.merate.mi.astro.it/utenti/covino
 
@@ -15,6 +15,7 @@ Remarks :
 History : (28/09/2010) First version.
         : (01/10/2010) Sextractor command names.
         : (05/02/2012) Better path management.
+        : (18/08/2013) ROS2 parameters.
 
 
 """
@@ -35,10 +36,13 @@ GenParSet       = ("SRPParamIn", "SRPConvIn", "SRPNnwIn", "SRPSexIn")
 
 SRPSEXPARDICT   = {"LS-LASC":('SRPParamIn','SRPConvLSLASCIn','SRPNnwIn','SRPSexLSLASCIn'),
                     "REM-ROSS":('SRPParamIn','SRPConvIn','SRPNnwIn','SRPSexREMROSSIn'),
+                    "REM-ROS2":('SRPParamIn','SRPConvIn','SRPNnwIn','SRPSexREMROS2In'),
                     "REM-REMIR":('SRPParamIn','SRPConvIn','SRPNnwIn','SRPSexREMREMIRIn'),
                     "TNG-LRS":('SRPParamIn','SRPConvIn','SRPNnwIn','SRPSexTNGLRSIn')}
 
 
 # SExtractor commands
 SRPsex	       = "sex"
-SRPsex_cyg     = "sex.exe"
\ No newline at end of file
+SRPsex_cyg     = "sex.exe"
+
+#
\ No newline at end of file
