@@ -2,12 +2,12 @@
 
 Context : SRP
 Module  : SRPUtil.py
-Version : 1.20.5
+Version : 1.22.0
 Status  : approved
 Author  : Stefano Covino, Nino Cucchiara
-Date    : 30/10/2011
+Date    : 11/02/2013
 E-mail  : stefano.covino@brera.inaf.it
-URL:    : http://www.merate.mi.astro.it/~covino
+URL:    : http://www.merate.mi.astro.it/utenti/covino
 Purpose : Collection of utility functions and classes for SRP.
 
 Usage   : to be imported
@@ -43,7 +43,9 @@ History : (29/05/2003) First version.
         : (21/03/2011) Better coding for extinction routines.
         : (20/08/2011) Exptime in StarData.
         : (23/10/2011) No more Jy 2 ergs/s cm2 A and viceversa conversion.
-        : (30/10/2011) Ellpticity added to StarData class.
+        : (30/10/2011) Ellipticity added to StarData class.
+        : (18/12/2012) Airmass in Daophot and GAIA output.
+        : (11/02/2013) Classification added to StarData class.
 """
 
 
@@ -85,6 +87,7 @@ class StarData:
         self.fmax = float(dlista[10])
         self.FWHM = float(dlista[11])
         self.Ellipticity = float(dlista[12])
+        self.Classification = float(dlista[13])
         self.mag = self.mag + 2.5*math.log10(exptime)
         self.magap = self.magap + 2.5*math.log10(exptime)
         self.magap = self.magap + zpl[0] - 25.0
@@ -100,7 +103,8 @@ class StarData:
         ostr = "%10s\t%7.2f\t%7.2f\t%10.6f\t%10.6f\t" % (self.Id, self.X, self.Y, self.RA, self.DEC)
         ostr = ostr + "%7.3f\t%6.3f\t%9.3f\t%15.3f\t" % (self.magap, self.emagap, self.sky, self.fmax)
         ostr = ostr + "%7.3f\t%6.3f\t%5.2f\t%15s\t" % (self.mag, self.emag, self.FWHM, self.MJD)
-        ostr = ostr + "%7.3f\t%15s\t%7.2f\t%7.2f" % (self.Airmass, self.Filter, self.Exptime, self.Ellipticity)
+        ostr = ostr + "%7.3f\t%15s\t%7.2f\t%7.2f\t" % (self.Airmass, self.Filter, self.Exptime, self.Ellipticity)
+        ostr = ostr + "%5.2f" % (self.Classification)
         return ostr+os.linesep
 
 
@@ -110,7 +114,7 @@ def getStarData (dlista,exptime, zpl=(25.0,0.0), mjd=-99.0, arm=1.0, flt='Unknow
     for i in range(len(dlista)):
         if dlista[i] != '':
             l = string.split(dlista[i])
-            if len(l) > 0 and l[0] != '>' and len(l) == 13:
+            if len(l) > 0 and l[0] != '>' and len(l) == 14:
                 s = StarData(l,exptime,zpl,mjd,arm,flt)
                 slista.append(s)
     return slista
@@ -241,7 +245,7 @@ def rad2deg(ang):
 # DAOPHOT data
 
 class DAOStarApData:
-    def __init__ (self, exptime, n, x, y, maglist, emaglist, sky, esky, skew, zp):
+    def __init__ (self, exptime, n, x, y, maglist, emaglist, sky, esky, skew, zp, am):
         self.Id = int(n)
         self.X = float(x)
         self.Y = float(y)
@@ -254,6 +258,7 @@ class DAOStarApData:
         self.Sky = float(sky)
         self.eSky = float(esky)
         self.SSkew = float(skew)
+        self.Airmass = float(am)
 
     def __str__ (self):
         msg = ''
@@ -261,12 +266,13 @@ class DAOStarApData:
         msg = msg + "\t%10.2f\t%10.2f\t%10.2f" % (self.Sky, self.eSky, self.SSkew)
         for i in range(len(self.MagList)):
             msg = msg + "\t%8.3f\t%8.3f" % (self.MagList[i], self.eMagList[i])
+        msg = msg + "\t%8.3f" % (self.Airmass)
         return msg
 
 
 
 class DAOStarPsfData:
-    def __init__ (self, exptime, n, x, y, sky, it, chi, sharp, mag, emag, zp):
+    def __init__ (self, exptime, n, x, y, sky, it, chi, sharp, mag, emag, zp, am):
         self.Id = int(n)
         self.X = float(x)
         self.Y = float(y)
@@ -276,12 +282,14 @@ class DAOStarPsfData:
         self.nIt = int(float(it))
         self.Chi = float(chi)
         self.Sharp = float(sharp)
+        self.Airmass = float(am)
 
     def __str__ (self):
         msg = ''
         msg = msg + "%6d\t%10.3f\t%10.3f" % (self.Id, self.X, self.Y)
         msg = msg + "\t%10.2f\t%4d\t%5.1f" % (self.Sky, self.nIt, self.Chi)
         msg = msg + "\t%5.1f\t%8.3f\t%8.3f" % (self.Sharp, self.Mag, self.eMag)
+        msg = msg + "\t%8.3" % (self.Airmass)
         return msg
 
 
@@ -405,7 +413,7 @@ def XAbsorption (energy, nh=1e20, z=0):
 # GAIA data
 
 class GAIAStarData:
-    def __init__ (self, exptime, n, x, y, mag, emag, sky, totsignal, radius, zp):
+    def __init__ (self, exptime, n, x, y, mag, emag, sky, totsignal, radius, zp, am):
         self.Id = int(n)
         self.X = float(x)
         self.Y = float(y)
@@ -414,6 +422,7 @@ class GAIAStarData:
         self.Sky = float(sky)
         self.TotSignal = float(totsignal)
         self.Radius = [float(radius[0]), float(radius[1])*float(radius[0]), float(radius[2])*float(radius[0])]
+        self.Airmass = am
 
     def __str__ (self):
         msg = ''
@@ -421,6 +430,7 @@ class GAIAStarData:
         msg = msg + "\t%8.3f\t%8.3f" % (self.Mag, self.eMag)
         msg = msg + "\t%10.2f\t%10g" % (self.Sky, self.TotSignal)
         msg = msg + "\t%6.2f\t%6.2f\t%6.2f" % (self.Radius[0],self.Radius[1],self.Radius[2])
+        msg = msg + "\t%8.3f" % (self.Airmass)
         return msg
 
 
