@@ -2,9 +2,9 @@
 
 Context : SRP
 Module  : SRP
-Version : 1.1.30
+Version : 1.1.36
 Author  : Stefano Covino
-Date    : 16/10/2013
+Date    : 05/02/2014
 E-mail  : stefano.covino@brera.inaf.it
 URL     : http://www.me.oa-brera.inaf.it/utenti/covino
 
@@ -107,6 +107,12 @@ History : (28/09/2010) First named version.
         : (02/09/2013) V. 3.10.12b5.
         : (03/09/2013) V. 3.10.12b6.
         : (16/10/2013) V. 3.10.12b7 and 3.10.12
+        : (04/11/2013) V. 3.10.13b1.
+        : (15/11/2013) V. 3.10.13b2.
+        : (09/01/2014) V. 3.10.13b3.
+        : (21/01/2014) V. 3.10.13b4.
+        : (28/01/2014) V. 3.10.13b5.
+        : (05/02/2014) V. 3.10.13.
 """
 
 
@@ -121,5 +127,6 @@ __all__ = ['SRPCatalogue', 'SRPFits', 'SRPFrames', 'SRPMath', 'SRPNet', 'SRPPhot
 
 
 # Version
-__version__ = '3.10.12'
+__version__ = '3.10.13'
 
+#
\ No newline at end of file
